==> zio-aws-datasync_2.12-5.17.112.1-sources.jar: zio/aws/datasync/model/CreateLocationS3Response.scala <==
package zio.aws.datasync.model
import zio.aws.datasync.model.primitives.LocationArn
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateLocationS3Response(
    locationArn: Option[LocationArn] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datasync.model.CreateLocationS3Response = {
    import CreateLocationS3Response.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datasync.model.CreateLocationS3Response
      .builder()
      .optionallyWith(
        locationArn.map(value => LocationArn.unwrap(value): java.lang.String)
      )(_.locationArn)
      .build()
  }
  def asReadOnly: zio.aws.datasync.model.CreateLocationS3Response.ReadOnly =
    zio.aws.datasync.model.CreateLocationS3Response.wrap(buildAwsValue())
}
object CreateLocationS3Response {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datasync.model.CreateLocationS3Response
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datasync.model.CreateLocationS3Response =
      zio.aws.datasync.model
        .CreateLocationS3Response(locationArn.map(value => value))
    def locationArn: Option[LocationArn]
    def getLocationArn: ZIO[Any, AwsError, LocationArn] =
      AwsError.unwrapOptionField("locationArn", locationArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datasync.model.CreateLocationS3Response
  ) extends zio.aws.datasync.model.CreateLocationS3Response.ReadOnly {
    override val locationArn: Option[LocationArn] = scala
      .Option(impl.locationArn())
      .map(value => zio.aws.datasync.model.primitives.LocationArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.datasync.model.CreateLocationS3Response
  ): zio.aws.datasync.model.CreateLocationS3Response.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-datasync_2.12-5.20.22.3-sources.jar: zio/aws/datasync/model/CreateLocationS3Response.scala <==
package zio.aws.datasync.model
import zio.aws.datasync.model.primitives.LocationArn
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateLocationS3Response(
    locationArn: Optional[LocationArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datasync.model.CreateLocationS3Response = {
    import CreateLocationS3Response.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datasync.model.CreateLocationS3Response
      .builder()
      .optionallyWith(
        locationArn.map(value => LocationArn.unwrap(value): java.lang.String)
      )(_.locationArn)
      .build()
  }
  def asReadOnly: zio.aws.datasync.model.CreateLocationS3Response.ReadOnly =
    zio.aws.datasync.model.CreateLocationS3Response.wrap(buildAwsValue())
}
object CreateLocationS3Response {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datasync.model.CreateLocationS3Response
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datasync.model.CreateLocationS3Response =
      zio.aws.datasync.model
        .CreateLocationS3Response(locationArn.map(value => value))
    def locationArn: Optional[LocationArn]
    def getLocationArn: ZIO[Any, AwsError, LocationArn] =
      AwsError.unwrapOptionField("locationArn", locationArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datasync.model.CreateLocationS3Response
  ) extends zio.aws.datasync.model.CreateLocationS3Response.ReadOnly {
    override val locationArn: Optional[LocationArn] = zio.aws.core.internal
      .optionalFromNullable(impl.locationArn())
      .map(value => zio.aws.datasync.model.primitives.LocationArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.datasync.model.CreateLocationS3Response
  ): zio.aws.datasync.model.CreateLocationS3Response.ReadOnly = new Wrapper(
    impl
  )
}
